import base64
import logging
import os
from nameko.dependency_providers import Config
from nameko.rpc import rpc

logger = logging.getLogger(__name__)

SYSTEM_NAME = os.getenv('SYSTEM_NAME', 'asterisk')


class FileService:
    name = '{}_files'.format(SYSTEM_NAME)
    config = Config()

    @rpc
    def ping(self):
        return 'pong'

    @rpc
    def put_file(self, path, data):
        logger.debug('Put file %s.', path)
        try:
            open(path, 'wb').write(base64.b64decode(data.encode()))
        except Exception:
            logger.exception('Put error:')
            return False
        return True

    @rpc
    def delete_file(self, path):
        logger.debug('Delete fle %s.', path)
        os.unlink(path)
        return True

    @rpc
    def get_file(self, path):
        logger.debug('Get file %s.', path)
        file_data = open(path, 'rb').read()
        return {
            'file_data': base64.b64encode(file_data).decode(),
        }

    @rpc
    def get_config(self, file):
        etc_dir = self.config.get('ASTERISK_ETC_DIR', '/etc/asterisk/')
        res = self.get_file(os.path.join(etc_dir, file))
        return res

    @rpc
    def put_config(self, file, data):
        etc_dir = self.config.get('ASTERISK_ETC_DIR', '/etc/asterisk/')
        res = self.put_file(os.path.join(etc_dir, file), data)
        return res

    @rpc
    def delete_config(self, file, data):
        etc_dir = self.config.get('ASTERISK_ETC_DIR', '/etc/asterisk/')
        self.delete_file(os.path.join(etc_dir, file))
        return True

    @rpc
    def get_all_configs(self):
        files = {}
        etc_dir = self.config.get('ASTERISK_ETC_DIR', '/etc/asterisk/')
        for file in os.listdir(etc_dir):
            files[file] = self.get_file(os.path.join(etc_dir, file))
        logger.debug('Get %s configs.', len(files.keys()))
        return files

    @rpc
    def put_all_configs(self, data):
        etc_dir = self.config.get('ASTERISK_ETC_DIR', '/etc/asterisk/')
        for filename, filedata in data.items():
            self.put_file(os.path.join(etc_dir, filename), filedata)
        logger.debug('Put %s configs.', len(data.keys()))
        return True
